==> endeavour_2.5.7.orig.tar.gz: endeavour-2.5.7/endeavour2/fsck.front/config.h <==
/*
           Endeavour FSCK Front End Compile Time Configuration
 */

#ifndef CONFIG_FSCK_H
#define CONFIG_FSCK_H

#include "../config.h"


/*
 *      Program name and version:
 */
#ifdef PROG_NAME
# undef PROG_NAME
#endif

#define PROG_NAME	"File System Check"



/*
 *	Standard output help message:
 */
#ifdef PROG_HELP_MESG
# undef PROG_HELP_MESG
#endif

#ifdef PROG_LANGUAGE_ENGLISH
#define PROG_HELP_MESG  "\
Usage: fsck.front [device] [options] [GUI_options]\n\
\n\
    [device] specifies the device to select at startup.\n\
\n\
    [options] can be any of the following:\n\
\n\
        --start                 Start check at startup.\n\
        -s                      Same as --start.\n\
        --help                  Prints (this) help screen and exits.\n\
        --version               Prints version information and exits.\n\
\n\
    [GUI_options] can be any options standard to your GUI, consult\n\
    your GUI's manual for available options.\n\
\n"
#endif
#ifdef PROG_LANGUAGE_SPANISH
#define PROG_HELP_MESG	"\
El uso: fsck.front [device] [options] [GUI_options]\n\
\n\
    [device] especifica el artefacto para escoger en inicio.\n\
\n\
    [options] puede ser cualquiera de lo Siguiente:\n\
\n\
        --start                 Cheque de Comienzo de comienzo en inicio.\n\
        -s                      Mismo que --start.\n\
        --help                  Pantalla de ayuda de Impresiones (esto) de ayuda y salidas.\n\
        --version               Versin Imprime informacin de versin y salidas.\n\
\n\
    [GUI_options] puede ser cualquier estndar de las opcin a su GUI,\n\
    consulta su manual de GUI para opciones disponibles.\n\
\n"
#endif
#ifdef PROG_LANGUAGE_FRENCH
#define PROG_HELP_MESG  "\
Usage: fsck.front [device] [options] [GUI_options]\n\
\n\
    [device] spcifie l'appareil pour choisir au dmarrage.\n\
\n\
    [options] peut tre n'importe quel du suivre:\n\
\n\
        --start                 Le Controle est lanc au dmarrage.\n\
        -s                      Mme comme --start.\n\
        --help                  Affiche cran d'aide cran et sort.\n\
        --version               Affiche information de version et sort.\n\
\n\
    [GUI_options] peut tre n'importe quelle norme d'options  votre\n\
    GUI, consulter le manuel de votre GUI pour les options disponibles.\n\
\n"
#endif


/*
 *	FSCK programs:
 *
 *	Do not specify full path in order to allow automatic locating
 *	by checking locations specified in the PATH environment.
 */
#define FSCK_PROG		"fsck"


#endif	/* CONFIG_FSCK_H */

==> endeavour_2.8.2.orig.tar.gz: endeavour-2.8.2/endeavour2/fsck.front/config.h <==
/*
	   Endeavour FSCK Front End Compile Time Configuration
 */

#ifndef CONFIG_FSCK_H
#define CONFIG_FSCK_H

#include "../config.h"


/*
 *      Program name and version:
 */
#ifdef PROG_NAME
# undef PROG_NAME
#endif

#define PROG_NAME	"File System Check"



/*
 *	Standard output help message:
 */
#ifdef PROG_HELP_MESG
# undef PROG_HELP_MESG
#endif

#ifdef PROG_LANGUAGE_ENGLISH
#define PROG_HELP_MESG  "\
Usage: fsck.front [device] [options] [GUI_options]\n\
\n\
    The [device] specifies the device to select at startup.\n\
\n\
    The [options] can be any of the following:\n\
\n\
	--start                 Start check at startup.\n\
	-s                      Same as --start.\n\
	--help                  Prints (this) help screen and exits.\n\
	--version               Prints version information and exits.\n\
\n\
    [GUI_options] can be any options standard to your GUI, consult\n\
    your GUI's manual for available options.\n\
\n"
#endif
#ifdef PROG_LANGUAGE_SPANISH
#define PROG_HELP_MESG	"\
El uso: fsck.front [device] [options] [GUI_options]\n\
\n\
    [device] especifica el artefacto para escoger en inicio.\n\
\n\
    [options] puede ser cualquiera de lo Siguiente:\n\
\n\
	--start                 Cheque de Comienzo de comienzo en inicio.\n\
	-s                      Mismo que --start.\n\
	--help                  Pantalla de ayuda de Impresiones (esto) de ayuda y salidas.\n\
	--version               Versin Imprime informacin de versin y salidas.\n\
\n\
    [GUI_options] puede ser cualquier estndar de las opcin a su GUI,\n\
    consulta su manual de GUI para opciones disponibles.\n\
\n"
#endif
#ifdef PROG_LANGUAGE_FRENCH
#define PROG_HELP_MESG  "\
Usage: fsck.front [device] [options] [GUI_options]\n\
\n\
    [device] spcifie l'appareil pour choisir au dmarrage.\n\
\n\
    [options] peut tre n'importe quel du suivre:\n\
\n\
	--start                 Le Controle est lanc au dmarrage.\n\
	-s                      Mme comme --start.\n\
	--help                  Affiche cran d'aide cran et sort.\n\
	--version               Affiche information de version et sort.\n\
\n\
    [GUI_options] peut tre n'importe quelle norme d'options  votre\n\
    GUI, consulter le manuel de votre GUI pour les options disponibles.\n\
\n"
#endif


/*
 *	FSCK programs:
 *
 *	Do not specify full path in order to allow automatic locating
 *	by checking locations specified in the PATH environment.
 */
#define FSCK_PROG		"fsck"


#endif	/* CONFIG_FSCK_H */
